@@ -3,31 +3,99 @@ common method
 '''
 
 import os
+import sys
 import json
 import socket
 import shutil
+import importlib
+from importlib import reload
 from loguru import logger
 from script_client.const import config,fm
 from script_client.common.my_requests import MyRequests
 
 
-def replace_str(s):
-    s = s.replace('\r\n', '')
-    s = s.replace('\n', '')
-    return s
 
+def find_script():
+    l=[]
+    if os.path.exists(os.sep.join([config.work_path,'test_script'])):
+        for root, dirs, files in os.walk(os.sep.join([config.work_path,'test_script'])):
+            for file in files:
+                if os.path.splitext(file)[1] == '.py':
+                    l.append(os.path.splitext(file)[0])
+        return l
+    else:
+        return False
 
-def get_local_ip():
-    local_ip = ""
+def save_script(f_path,f_text):
     try:
-        socket_objs = [socket.socket(socket.AF_INET, socket.SOCK_DGRAM)]
-        ip_from_ip_port = [(s.connect(("8.8.8.8", 53)), s.getsockname()[0], s.close()) for s in socket_objs][0][1]
-        ip_from_host_name = [ip for ip in socket.gethostbyname_ex(socket.gethostname())[2] if
-                             not ip.startswith("127.")][:1]
-        local_ip = [l for l in (ip_from_ip_port, ip_from_host_name) if l][0]
-    except (Exception) as e:
-        print("get_local_ip found exception : %s" % e)
-    return local_ip if ("" != local_ip and None != local_ip) else socket.gethostbyname(socket.gethostname())
+        with open(f_path, 'w', encoding='utf-8') as f:
+            f.write(f_text)
+        return True
+    except Exception as e:
+        return e
+
+def upload_script(f_path,files):
+    try:
+        for meta in files:
+            with open(f_path, 'wb+') as f:
+                f.write(meta['body'])
+        return True
+    except Exception as e:
+        return e
+
+def del_script(f_path):
+    try:
+        pass
+        return True
+    except Exception as e:
+        return e
+
+def import_and_regist():
+    # import
+    l = find_script()
+    if l != False :
+        for i in l:
+            importlib.import_module(f"test_script.{i}")
+    # regist
+    ret = regist_app()
+    if ret == True:
+        logger.info(f"注册映射关系完成")
+        return True
+    return False
+
+def reload_script():
+    l = (find_script())
+    # print(sys.modules.keys())
+    fm.empty_map()
+    for i in l:
+        module = sys.modules['test_script.'+i]
+        reload(module)
+        # print(f"reload了{i}")
+    regist_app()
+
+
+def get_tree():
+    tree = [
+        {
+            "title": "test_script",
+            'spread': 'true',
+            # "children": [
+            #     {
+            #         "title": "西安",
+            #     },
+            #     {
+            #         "title": "延安",
+            #     }
+            # ]
+        }
+    ]
+    children = []
+    l = find_script()
+    if l != False:
+        for i in l:
+            children.append({'title': i})
+    tree[0]['children'] = children
+    return tree
 
 
 def is_none(kwargs):
@@ -109,7 +177,8 @@ def regist_app():
                 t_l = []
                 for vvv in vv:
                     for kkkk, vvvv in vvv.items():
-                        t_l.append(kkkk.__name__)
+                        t_j = {'name':vvvv['name'],'value':kkkk.__name__}
+                        t_l.append(t_j)
                 tt_d = {'moniter_path': kk, 'function': t_l}
                 t_d['path'].append(tt_d)
             data['registry'].append(t_d)
@@ -130,9 +199,28 @@ def regist_app():
 
 
 def str_to_dict(str):
-    str = str.replace(r'\r\n', '')
-    str = str.replace("'", '"')
-    return json.loads(str)
+    str_t = str.replace(r'\r\n', '')
+    str_e = str_t.replace("'", '"')
+    return json.loads(str_e)
+
+def replace_str(s):
+    s = s.replace('\r\n', '')
+    s = s.replace('\n', '')
+    return s
+
+
+def get_local_ip():
+    local_ip = ""
+    try:
+        socket_objs = [socket.socket(socket.AF_INET, socket.SOCK_DGRAM)]
+        ip_from_ip_port = [(s.connect(("8.8.8.8", 53)), s.getsockname()[0], s.close()) for s in socket_objs][0][1]
+        ip_from_host_name = [ip for ip in socket.gethostbyname_ex(socket.gethostname())[2] if
+                             not ip.startswith("127.")][:1]
+        local_ip = [l for l in (ip_from_ip_port, ip_from_host_name) if l][0]
+    except (Exception) as e:
+        print("get_local_ip found exception : %s" % e)
+    return local_ip if ("" != local_ip and None != local_ip) else socket.gethostbyname(socket.gethostname())
+
 
 
 if "__main__" == __name__:
