@@ -5,7 +5,7 @@ from script_client.const import fm
 
 
 
-def register(app='',path='',timeout=0):
+def register(app='',path='',name='',timeout=0):
     '''
     注册为回调函数
     :param app: app_code
@@ -14,7 +14,8 @@ def register(app='',path='',timeout=0):
     :return:
     '''
     def deco(func):
-        fm.add_map(app=app.strip(),path=path.strip(),func=func,timeout=timeout)
+        fm.add_map(app=app.strip(),path=path.strip(),func=func,
+                   name=name,timeout=timeout)
         def wrapper(*args, **kwargs):
             return func(*args, **kwargs)
         return wrapper
