@@ -1,4 +1,5 @@
 
+import json
 import queue
 import requests
 import threading
@@ -17,7 +18,7 @@ q = None
 
 def _send_resurl(data):
     url = config.result_url
-    # logger.debug(f"{data}")
+    logger.info(f"{data}")
     mr = MyRequests(config.http_request_timeout)
     try:
         rep = mr.run(url=url, method='post',json=data)
@@ -86,29 +87,39 @@ class MyThread(threading.Thread):
                     'system_key':data['system_key'],
                     'app_code': data['app_code'],
                     'moniter_path': data['moniter_path'],
+                    'http_body':data['http_body'],
+                    'scrfun_name':data['func_obj'][0].__name__,
+                    'name':data['func_obj'][1]['name'],
                     'result':1,  # 0失败，1通过
                     'result_body': {
                         'type': 0,  # 0=无异常,1=过程异常，2=断言异常
-                        'stdout':data['http_body'],
-                        'stderr':'',
+                        'result_msg':'',
                     }
                 }
                 try:
-                    data['func_obj'][0](data)
+                    ret = data['func_obj'][0](data)
+                    ret_data['result_body']['type'] = 0
+                    ret_data['result_body']['result_msg'] = ret
+                    try:
+                        if ret:
+                            json.dumps(ret)
+                    except Exception:
+                        ret_data['result_body']['result_msg'] = str(ret)
+
                 except AssertionError as e:
                     ret_data['result']=0
                     ret_data['result_body']['type'] = 2
-                    ret_data['result_body']['stderr'] = repr(e)
+                    ret_data['result_body']['result_msg'] = repr(e)
                 except Exception as e:
                     ret_data['result'] = 0
                     ret_data['result_body']['type'] = 1
-                    ret_data['result_body']['stderr'] = repr(e)
+                    ret_data['result_body']['result_msg'] = repr(e)
                 finally:
                     _send_resurl(ret_data)
                     pass
                 self.queue.task_done()
             except Exception as e:
-                logger.info(f"{e}")
+                logger.error(f"{e}")
 
 
 class MyThreadPool():
@@ -123,7 +134,7 @@ def init_thread_pool():
     global q
     q = queue.Queue(config.max_task)
     MyThreadPool(queue=q, size=config.max_thread)
-    logger.info(f"线程池初始化完成")
+    logger.info(f"任务池初始化完成")
 
 
 if __name__ == '__main__':
